| Title: | Find details about R packages on CRAN or github |
|---|---|
| Description: | Finds meta data for all packages on CRAN that match a given author and packages contained in specified github repositories. |
| Authors: | Rob Hyndman [aut, cre] (ORCID: <https://orcid.org/0000-0002-2140-5352>) |
| Maintainer: | Rob Hyndman <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.0 |
| Built: | 2026-05-31 09:39:35 UTC |
| Source: | https://github.com/robjhyndman/pkgmeta |
Find meta data for all packages on CRAN that match a given author and all packages contained in
a vector of github repositories and return as a tibble. Meta data on packages that are
both on CRAN and github will be combined into a single row. Where meta data clash, the
CRAN version is preferred when prefer_cran is TRUE, otherwise the github
version is preferred.
get_meta( cran_authors = NULL, include_downloads = FALSE, start = "2000-01-01", end = Sys.Date(), cran_packages = NULL, github_repos = NULL, prefer_cran = TRUE )get_meta( cran_authors = NULL, include_downloads = FALSE, start = "2000-01-01", end = Sys.Date(), cran_packages = NULL, github_repos = NULL, prefer_cran = TRUE )
cran_authors |
Character vector to find in CRAN author names |
include_downloads |
Should total CRAN downloads since |
start |
Start date for download statistics. Ignored if |
end |
End date for download statistics. Ignored if |
cran_packages |
Character vector of CRAN packages. Ignored if |
github_repos |
Character vector of github repos |
prefer_cran |
When a package is both on CRAN and github, which information should be preferenced? |
get_meta(cran_authors = "Hyndman") get_meta(github_repos = c("robjhyndman/forecast", "earowang/hts")) get_meta(cran_authors = "Emi Tanaka", github_repos = c("numbats/yowie", "numbats/monash"))get_meta(cran_authors = "Hyndman") get_meta(github_repos = c("robjhyndman/forecast", "earowang/hts")) get_meta(cran_authors = "Emi Tanaka", github_repos = c("numbats/yowie", "numbats/monash"))